EXPORTS
	??1CMMFDevSoundAdaptation@@UAE@XZ @ 1 NONAME ; CMMFDevSoundAdaptation::~CMMFDevSoundAdaptation(void)
	?CancelInitialize@CMMFDevSoundAdaptation@@QAEHXZ @ 2 NONAME ; int CMMFDevSoundAdaptation::CancelInitialize(void)
	?Capabilities@CMMFDevSoundAdaptation@@QAEHAAVTMMFCapabilities@@@Z @ 3 NONAME ; int CMMFDevSoundAdaptation::Capabilities(class TMMFCapabilities &)
	?ClientConfig@CMMFDevSoundAdaptation@@QBEABVTMMFClientConfig@@XZ @ 4 NONAME ; class TMMFClientConfig const & CMMFDevSoundAdaptation::ClientConfig(void) const
	?CloseDevSound@CMMFDevSoundAdaptation@@QAEHXZ @ 5 NONAME ; int CMMFDevSoundAdaptation::CloseDevSound(void)
	?Config@CMMFDevSoundAdaptation@@QBE?AVTMMFCapabilities@@XZ @ 6 NONAME ; class TMMFCapabilities CMMFDevSoundAdaptation::Config(void) const
	?CustomInterface@CMMFDevSoundAdaptation@@QAEPAXVTUid@@@Z @ 7 NONAME ; void * CMMFDevSoundAdaptation::CustomInterface(class TUid)
	?EmptyBuffers@CMMFDevSoundAdaptation@@QAEHXZ @ 8 NONAME ; int CMMFDevSoundAdaptation::EmptyBuffers(void)
	?FixedSequenceCount@CMMFDevSoundAdaptation@@QAEHXZ @ 9 NONAME ; int CMMFDevSoundAdaptation::FixedSequenceCount(void)
	?FixedSequenceName@CMMFDevSoundAdaptation@@QAEABVTDesC16@@H@Z @ 10 NONAME ; class TDesC16 const & CMMFDevSoundAdaptation::FixedSequenceName(int)
	?Gain@CMMFDevSoundAdaptation@@QAEHXZ @ 11 NONAME ; int CMMFDevSoundAdaptation::Gain(void)
	?GetPlayBalanceL@CMMFDevSoundAdaptation@@QAEXAAH0@Z @ 12 NONAME ; void CMMFDevSoundAdaptation::GetPlayBalanceL(int &, int &)
	?GetRecordBalanceL@CMMFDevSoundAdaptation@@QAEXAAH0@Z @ 13 NONAME ; void CMMFDevSoundAdaptation::GetRecordBalanceL(int &, int &)
	?GetSupportedInputDataTypesL@CMMFDevSoundAdaptation@@QBEXAAV?$RArray@VTFourCC@@@@ABVTMMFPrioritySettings@@@Z @ 14 NONAME ; void CMMFDevSoundAdaptation::GetSupportedInputDataTypesL(class RArray<class TFourCC> &, class TMMFPrioritySettings const &) const
	?GetSupportedOutputDataTypesL@CMMFDevSoundAdaptation@@QBEXAAV?$RArray@VTFourCC@@@@ABVTMMFPrioritySettings@@@Z @ 15 NONAME ; void CMMFDevSoundAdaptation::GetSupportedOutputDataTypesL(class RArray<class TFourCC> &, class TMMFPrioritySettings const &) const
	?InitializeL@CMMFDevSoundAdaptation@@QAEXVTFourCC@@W4TMMFState@@@Z @ 16 NONAME ; void CMMFDevSoundAdaptation::InitializeL(class TFourCC, enum TMMFState)
	?InitializeL@CMMFDevSoundAdaptation@@QAEXVTUid@@W4TMMFState@@@Z @ 17 NONAME ; void CMMFDevSoundAdaptation::InitializeL(class TUid, enum TMMFState)
	?InitializeL@CMMFDevSoundAdaptation@@QAEXW4TMMFState@@@Z @ 18 NONAME ; void CMMFDevSoundAdaptation::InitializeL(enum TMMFState)
	?MaxGain@CMMFDevSoundAdaptation@@QAEHXZ @ 19 NONAME ; int CMMFDevSoundAdaptation::MaxGain(void)
	?MaxVolume@CMMFDevSoundAdaptation@@QAEHXZ @ 20 NONAME ; int CMMFDevSoundAdaptation::MaxVolume(void)
	?NewL@CMMFDevSoundAdaptation@@SAPAV1@AAVMDevSoundAdaptationObserver@@AAVMGlobalProperties@@@Z @ 21 NONAME ; class CMMFDevSoundAdaptation * CMMFDevSoundAdaptation::NewL(class MDevSoundAdaptationObserver &, class MGlobalProperties &)
	?Pause@CMMFDevSoundAdaptation@@QAEHXZ @ 22 NONAME ; int CMMFDevSoundAdaptation::Pause(void)
	?PlayDTMFStringL@CMMFDevSoundAdaptation@@QAEXABVTDesC16@@@Z @ 23 NONAME ; void CMMFDevSoundAdaptation::PlayDTMFStringL(class TDesC16 const &)
	?PlayData@CMMFDevSoundAdaptation@@QAEXXZ @ 24 NONAME ; void CMMFDevSoundAdaptation::PlayData(void)
	?PlayDualToneL@CMMFDevSoundAdaptation@@QAEXHHABVTTimeIntervalMicroSeconds@@@Z @ 25 NONAME ; void CMMFDevSoundAdaptation::PlayDualToneL(int, int, class TTimeIntervalMicroSeconds const &)
	?PlayFixedSequenceL@CMMFDevSoundAdaptation@@QAEXH@Z @ 26 NONAME ; void CMMFDevSoundAdaptation::PlayFixedSequenceL(int)
	?PlayInitL@CMMFDevSoundAdaptation@@QAEXXZ @ 27 NONAME ; void CMMFDevSoundAdaptation::PlayInitL(void)
	?PlayToneL@CMMFDevSoundAdaptation@@QAEXHABVTTimeIntervalMicroSeconds@@@Z @ 28 NONAME ; void CMMFDevSoundAdaptation::PlayToneL(int, class TTimeIntervalMicroSeconds const &)
	?PlayToneSequenceL@CMMFDevSoundAdaptation@@QAEXABVTDesC8@@@Z @ 29 NONAME ; void CMMFDevSoundAdaptation::PlayToneSequenceL(class TDesC8 const &)
	?PostOpenL@CMMFDevSoundAdaptation@@QAEXXZ @ 30 NONAME ; void CMMFDevSoundAdaptation::PostOpenL(void)
	?ProcessingFinishedReceived@CMMFDevSoundAdaptation@@QAEHAAH@Z @ 31 NONAME ; int CMMFDevSoundAdaptation::ProcessingFinishedReceived(int &)
	?RecordData@CMMFDevSoundAdaptation@@QAEXXZ @ 32 NONAME ; void CMMFDevSoundAdaptation::RecordData(void)
	?RecordInitL@CMMFDevSoundAdaptation@@QAEXXZ @ 33 NONAME ; void CMMFDevSoundAdaptation::RecordInitL(void)
	?SamplesPlayed@CMMFDevSoundAdaptation@@QAEHXZ @ 34 NONAME ; int CMMFDevSoundAdaptation::SamplesPlayed(void)
	?SamplesRecorded@CMMFDevSoundAdaptation@@QAEHXZ @ 35 NONAME ; int CMMFDevSoundAdaptation::SamplesRecorded(void)
	?SetClientConfig@CMMFDevSoundAdaptation@@QAEHABVTMMFClientConfig@@@Z @ 36 NONAME ; int CMMFDevSoundAdaptation::SetClientConfig(class TMMFClientConfig const &)
	?SetConfigL@CMMFDevSoundAdaptation@@QAEXABVTMMFCapabilities@@@Z @ 37 NONAME ; void CMMFDevSoundAdaptation::SetConfigL(class TMMFCapabilities const &)
	?SetDTMFLengths@CMMFDevSoundAdaptation@@QAEHAAVTTimeIntervalMicroSeconds32@@00@Z @ 38 NONAME ; int CMMFDevSoundAdaptation::SetDTMFLengths(class TTimeIntervalMicroSeconds32 &, class TTimeIntervalMicroSeconds32 &, class TTimeIntervalMicroSeconds32 &)
	?SetGain@CMMFDevSoundAdaptation@@QAEHHAAH@Z @ 39 NONAME ; int CMMFDevSoundAdaptation::SetGain(int, int &)
	?SetPlayBalanceL@CMMFDevSoundAdaptation@@QAEXHHAAH@Z @ 40 NONAME ; void CMMFDevSoundAdaptation::SetPlayBalanceL(int, int, int &)
	?SetPrioritySettings@CMMFDevSoundAdaptation@@QAEHABVTMMFPrioritySettings@@@Z @ 41 NONAME ; int CMMFDevSoundAdaptation::SetPrioritySettings(class TMMFPrioritySettings const &)
	?SetRecordBalanceL@CMMFDevSoundAdaptation@@QAEXHHAAH@Z @ 42 NONAME ; void CMMFDevSoundAdaptation::SetRecordBalanceL(int, int, int &)
	?SetToneRepeats@CMMFDevSoundAdaptation@@QAEHHABVTTimeIntervalMicroSeconds@@@Z @ 43 NONAME ; int CMMFDevSoundAdaptation::SetToneRepeats(int, class TTimeIntervalMicroSeconds const &)
	?SetVolume@CMMFDevSoundAdaptation@@QAEHHAAH@Z @ 44 NONAME ; int CMMFDevSoundAdaptation::SetVolume(int, int &)
	?SetVolumeRamp@CMMFDevSoundAdaptation@@QAEHABVTTimeIntervalMicroSeconds@@@Z @ 45 NONAME ; int CMMFDevSoundAdaptation::SetVolumeRamp(class TTimeIntervalMicroSeconds const &)
	?Stop@CMMFDevSoundAdaptation@@QAEHXZ @ 46 NONAME ; int CMMFDevSoundAdaptation::Stop(void)
	?Volume@CMMFDevSoundAdaptation@@QAEHXZ @ 47 NONAME ; int CMMFDevSoundAdaptation::Volume(void)
	?CancelRegisterAsClient@CMMFDevSoundAdaptation@@QAEHVTUid@@@Z @ 48 NONAME ; int CMMFDevSoundAdaptation::CancelRegisterAsClient(class TUid)
	?GetResourceNotificationData@CMMFDevSoundAdaptation@@QAEHVTUid@@AAVTDes8@@@Z @ 49 NONAME ; int CMMFDevSoundAdaptation::GetResourceNotificationData(class TUid, class TDes8 &)
	?RegisterAsClient@CMMFDevSoundAdaptation@@QAEHVTUid@@ABVTDesC8@@@Z @ 50 NONAME ; int CMMFDevSoundAdaptation::RegisterAsClient(class TUid, class TDesC8 const &)
	?WillResumePlay@CMMFDevSoundAdaptation@@QAEHXZ @ 51 NONAME ; int CMMFDevSoundAdaptation::WillResumePlay(void)
	?GetTimePlayed@CMMFDevSoundAdaptation@@QAEHAAVTTimeIntervalMicroSeconds@@@Z @ 52 NONAME ; int CMMFDevSoundAdaptation::GetTimePlayed(class TTimeIntervalMicroSeconds &)
	?IsResumeSupported@CMMFDevSoundAdaptation@@QAEHXZ @ 53 NONAME ; int CMMFDevSoundAdaptation::IsResumeSupported(void)
	?Resume@CMMFDevSoundAdaptation@@QAEHXZ @ 54 NONAME ; int CMMFDevSoundAdaptation::Resume(void)
	?BufferErrorEvent@CMMFDevSoundAdaptation@@QAEXXZ @ 55 NONAME ; void CMMFDevSoundAdaptation::BufferErrorEvent(void)
	?ProcessingError@CMMFDevSoundAdaptation@@QAEHAAH@Z @ 56 NONAME ; int CMMFDevSoundAdaptation::ProcessingError(int &)
	?RollbackAdaptorActiveStateToBeforeCommit@CMMFDevSoundAdaptation@@QAEXXZ @ 57 NONAME ; void CMMFDevSoundAdaptation::RollbackAdaptorActiveStateToBeforeCommit(void)

